@@ -5,8 +5,9 @@
 ## has similar calling sequence as ode.2D from package deSolve
 ## =============================================================================
 
-steady.2D    <- function (y, time=0, func, parms=NULL, nspec=NULL, 
-                 dimens, names = NULL, cyclicBnd = NULL, ...)
+steady.2D    <- function (y, time = 0, func, parms = NULL, nspec = NULL, 
+                 dimens, names = NULL, method = "stodes", 
+                       jactype = NULL, cyclicBnd = NULL, times = time, ...)
 {
   if (any(!is.na(pmatch(names(list(...)), "jacfunc")))) 
     stop ("cannot run steady.2D with jacfunc specified - remove jacfunc from call list")
@@ -24,6 +25,14 @@ steady.2D    <- function (y, time=0, func, parms=NULL, nspec=NULL,
   if (! is.null(names) && length(names) != nspec)
     stop("length of 'names' should equal 'nspec'")
 
+  if (!method %in% c("stodes","runsteady"))
+    stop (" 'method' should be one of 'stodes', 'runsteady'")   
+
+  if (is.null(times))
+    times <- 0
+  if (method == "runsteady" & length(times) == 1)
+      times <- c(times, Inf)  
+
   Bnd <- c(0,0)
   if (! is.null(cyclicBnd)) {
     if (max(cyclicBnd) > 2 )
@@ -31,9 +40,18 @@ steady.2D    <- function (y, time=0, func, parms=NULL, nspec=NULL,
     Bnd[cyclicBnd[cyclicBnd>0]]<-1
   }
 
-  # Note: stodes expects rev(dimens)..
-  out <- stodes(y=y, time=time, func=func, parms=parms,
-                nnz=c(nspec,rev(dimens), rev(Bnd)), sparsetype = "2D", ...)
+  if (method == "stodes") {
+    if (is.null(jactype))
+      jactype <- "2D"
+    # Note: stodes expects rev(dimens)..
+     out <- stodes(y=y, time=times, func=func, parms=parms,
+                nnz=c(nspec,rev(dimens), rev(Bnd)), sparsetype = jactype, ...)
+  } else {
+    if (is.null(jactype))
+      jactype <- "sparse"
+    out <- runsteady (y=y,times = times,func=func,parms=parms,
+                jactype=jactype, ...)        # will use lsodes             
+  } 
   class(out) <- c("steady2D","rootSolve","list")    # a steady-state 
   attr(out,"dimens") <- dimens
   attr(out, "nspec") <- nspec
